from django.db import models


class AutoRepr(object):
    """A model mixin that generates a useful __repr__"""

    def _repr_format_field(self, field):
        """Get a "bar='bar_value'" str.

        field is a Django Field object.
        """
        if isinstance(field, models.ForeignKey):
            field_name = field.name + '_id'
        else:
            field_name = field.name
        return "{}={!r}".format(field_name, getattr(self, field_name))

    def __repr__(self):
        cls = type(self)
        fields = cls._meta.fields
        parts = map(self._repr_format_field, fields)
        attrs = ', '.join(parts)
        return '{}({})'.format(cls.__name__, attrs)




from setuptools import setup

setup(
    name='django-auto-repr',
    version='1.0',
    description='Give Django models a useful __repr__',
    url='https://github.com/dan-passaro/django-auto-repr',
    author='Dan Passaro',
    author_email='danpassaro@gmail.com',
    license='MIT',
    py_modules=['django_auto_repr'],
    install_requires=[
        'django',
    ]
)
